@@ -40,7 +40,8 @@ module Neovim
 
     def write(object)
       log(:debug) { {object: object} }
-      @packer.write(object).flush
+      @packer.write(object)
+      self
     end
 
     def read
@@ -49,6 +50,11 @@ module Neovim
       end
     end
 
+    def flush
+      @packer.flush
+      self
+    end
+
     def register_type(id)
       @unpacker.register_type(id) do |data|
         index = MessagePack.unpack(data)
