@@ -8,9 +8,6 @@ module Neovim
         @host = host
       end
 
-      # Load the provided Ruby files while temporarily overriding
-      # +Neovim.plugin+ to expose the remote plugin DSL and register the result
-      # to the host.
       def load(paths)
         paths.each do |path|
           override_plugin_method(path) do
@@ -27,7 +24,7 @@ module Neovim
 
         Neovim.define_singleton_method(:plugin) do |&block|
           plugin = Plugin.from_config_block(path, &block)
-          at_host.register(plugin)
+          at_host.plugins << plugin
         end
 
         yield
